OverlapError

Struct OverlapError 

pub struct OverlapError<T, V> {
    pub non_overlapping: RangeMap<T, V>,
    pub discarded: Vec<(Range<T>, V)>,
}
When creating a RangeMap from a list of ranges and values, there’s a possiblity that two ranges will overlap. In this case, it’s a problem if they want to be associated to different values (because we don’t know which value should be assigned to the intersection of the ranges). An OverlapError is the result of such a situation. It contains two members. The first is a RangeMap obtained by simply ignoring all the ranges that would cause a bad overlap. The second is the collection of ranges that were ignored.

Fields

non_overlapping: RangeMap<T, V>discarded: Vec<(Range<T>, V)>